{ inputs, lib, pkgs, ... }:
{
  imports = [
    inputs.apple-silicon.nixosModules.default
    ./hardware-configuration.nix
  ];

  # Generic Config
  nix.settings.experimental-features = [ "nix-command" "flakes" ];
  nixpkgs.hostPlatform = lib.mkDefault "aarch64-linux";
  time.timeZone = "America/New_York";

  # Enable SSDM
  reichardnix = {
    display-managers.sddm = {
      enable = true;
    };
  };

  # Boot Loader Config
  boot = {
    loader = {
      systemd-boot.enable = true;
      efi.canTouchEfiVariables = false;
    };
    kernelParams = [ "apple_dcp.show_notch=1" ];
  };

  # Networking Config
  networking = {
    firewall.enable = true;
    networkmanager.enable = true;
    networkmanager.wifi.backend = "iwd";
    useDHCP = lib.mkDefault true;
    wireless.iwd.enable = true;
  };

  # Hardware Config
  hardware = {
    asahi = {
      peripheralFirmwareDirectory = ./firmware;
      useExperimentalGPUDriver = true;
    };

    graphics.enable = true;
    bluetooth.enable = true;
    bluetooth.powerOnBoot = true;
  };

  # HyprLand Config
  programs.hyprland = {
    enable = true;
    withUWSM = true;
  };

  # System Packages
  environment.systemPackages = with pkgs; [
    ghostty
    htop
    tmux
    vim
    wget
  ];

  system.stateVersion = "24.11";
}
